@@ -5,12 +5,13 @@
 #' @param futime_var_new Name of the newly calculated variable for follow-up time. Default is p_futimeyrs.
 #' @param fu_end end of follow-up in time format YYYY-MM-DD.
 #' @param dattype can be "zfkd" or "seer" or NULL. Will set default variable names if dattype is "seer" or "zfkd". Default is NULL.
-#' @param check Check newly calculated variable p_status by printing frequency table. Default is TRUE.
+#' @param check Check newly calculated variable "p_futimeyrs" by printing frequency table. Default is TRUE.
 #' @param time_unit Unit of follow-up time (can be "days", "weeks", "months", "years"). Default is "years".
 #' @param status_var Name of the patient status variable that was previously created. Default is p_status.
 #' @param lifedat_var Name of variable containing Date of Death. Will override dattype preset.
 #' @param fcdat_var Name of variable containing Date of Primary Cancer diagnosis. Will override dattype preset.
 #' @param spcdat_var Name of variable containing Date of SPC diagnosis Will override dattype preset.
+#' @param quiet If TRUE, warnings and messages will be suppressed. Default is FALSE.
 #' @return wide_df
 #' @export
 #' @examples 
@@ -57,7 +58,8 @@ calc_futime_tt <- function(wide_df,
                            status_var = "p_status",
                            lifedat_var = NULL,
                            fcdat_var = NULL,
-                           spcdat_var = NULL){
+                           spcdat_var = NULL,
+                           quiet = FALSE){
   
   #fetch variable names provided in function call
   futime_var_new <- rlang::ensym(futime_var_new)
@@ -156,16 +158,23 @@ calc_futime_tt <- function(wide_df,
   
   #check whether FU date provided might be too late
   if(fu_end_param > max(wide_df[[rlang::as_name(fcdat_var)]], na.rm = TRUE) & fu_end_param > max(wide_df[[rlang::as_name(spcdat_var)]], na.rm = TRUE)) {
-    rlang::abort(paste0("You have provided an end of Follow-up date that might be out of range of the collected data.",
-                        "Thus events such as SPCs or deaths might not have been recorded and FU-time is overestimated.",
-                        "\nEnd of Follow-up provided: ", fu_end_param,
-                        "\nLatest recorded First Cancer: ",  max(wide_df[[rlang::as_name(fcdat_var)]], na.rm = TRUE),
-                        "\nLatest recorded Second Cancer: ",  max(wide_df[[rlang::as_name(spcdat_var)]], na.rm = TRUE)
-    ))
+    if(!quiet){
+      rlang::warn(c(
+        "i" = "You have provided an end of Follow-up date that might be out of range of the collected data.",
+        "Thus events such as SPCs or deaths might not have been recorded and FU-time is overestimated.",
+        " " = paste0("End of Follow-up provided: ", fu_end_param),
+        " " = paste0("Latest recorded First Cancer: ",  max(wide_df[[rlang::as_name(fcdat_var)]], na.rm = TRUE)),
+        " " = paste0("Latest recorded Second Cancer: ",  max(wide_df[[rlang::as_name(spcdat_var)]], na.rm = TRUE)),
+        "i" = paste0("End of follow-up will be set to: ",  max(wide_df[[rlang::as_name(spcdat_var)]], na.rm = TRUE))
+      ))
+    }
+    
+    fu_end_param <- max(wide_df[[rlang::as_name(spcdat_var)]], na.rm = TRUE)
+    fu_end_quo <- rlang::enquo(fu_end_param)
   }
   
   #check if new and old futime_var are the same --> message that id was overwritten
-  if(rlang::as_name(futime_var_new) %in% names(wide_df)){
+  if(!quiet & rlang::as_name(futime_var_new) %in% names(wide_df)){
     rlang::warn(paste0(rlang::as_name(futime_var_new)," is already present in dataset. Variable has been overwritten with new values."))
   }
   
@@ -175,7 +184,7 @@ calc_futime_tt <- function(wide_df,
   if(is.factor(wide_df[[rlang::as_name(status_var)]])){
     changed_status_var <- TRUE
     wide_df <- wide_df %>%
-      tidytable::mutate.(
+      tidytable::mutate(
         #copy old status var
         status_var_orig = !!status_var,
         #make status_var numeric
@@ -192,7 +201,7 @@ calc_futime_tt <- function(wide_df,
   #not working from here
   #calculate new follow_up time p_futimeyrs
   wide_df <- wide_df %>%
-    tidytable::mutate.(!!futime_var_new := tidytable::case.(
+    tidytable::mutate(!!futime_var_new := tidytable::case(
       #patient alive, after FC
       !!status_var == 1, lubridate::time_length(difftime(!!fu_end_quo, rlang::eval_tidy(!!fcdat_var)), !!time_unit),
       #patient alive, after SPC
@@ -214,12 +223,12 @@ calc_futime_tt <- function(wide_df,
   #if status_var was changed from factor to numeric, revert
   if(changed_status_var == TRUE){
     wide_df <- wide_df %>%
-      tidytable::mutate.(
+      tidytable::mutate(
         #replace temporary lifedat_var values with values from old lifedat_var
         !!status_var := status_var_orig
       ) %>%
       #remove status_var_orig
-      tidytable::select.(-status_var_orig)
+      tidytable::select(-status_var_orig)
   }
   
   #---- Checks end
@@ -227,7 +236,7 @@ calc_futime_tt <- function(wide_df,
   #conduct check on new variable
   if(check == TRUE){
     check_tab <- wide_df %>%
-      tidytable::summarise.(mean_futime = mean(!!futime_var_new, na.rm = TRUE),
+      tidytable::summarise(mean_futime = mean(!!futime_var_new, na.rm = TRUE),
                             min_futime = min(!!futime_var_new, na.rm = TRUE),
                             max_futime = max(!!futime_var_new, na.rm = TRUE),
                             median_futime = stats::median(!!futime_var_new, na.rm = TRUE),
