@@ -21,6 +21,7 @@
 #'                  "region" for region, "sex" for biological sex, "age" for age-groups (can be single ages or 5-year brackets), "year" for time period (can be single year or 5-year brackets), 
 #'                  "population_pyar" for person-years at risk in the respective age/sex/year cohort.
 #'                  refpop_df must use the same category coding of age, sex, region, year and site as age_var, sex_var, region_var, year_var and site_var.
+#' @param quiet If TRUE, warnings and messages will be suppressed. Default is FALSE.
 #' @return df
 #' @importFrom rlang .data
 #' @export 
@@ -49,7 +50,8 @@ calc_refrates <- function(df,
                           sex_var = NULL,
                           year_var = NULL,
                           race_var = NULL,    #optional when matching by race is wanted
-                          site_var = NULL) {
+                          site_var = NULL,
+                          quiet = FALSE) {
   
   # ---- 0 function basics ----
   
@@ -59,10 +61,14 @@ calc_refrates <- function(df,
   if(!(fill_sites[1] %in% c("no", "icd2d", "icd3d", "icd10gm2d", "sitewho", "sitewho_b",
                             "sitewho_num", "sitewho_b_num", "sitewho_epi", "sitewhogen",
                             "sitewhogen_num", "manual"))){
-    rlang::warn(paste0(
-      "Parameter `fill_sites` must be \"icd2d\", \"icd3d\", \"icd10gm2d\", \"sitewho\", \"sitewho_b\",", 
-      " \"sitewho_num\", \"sitewho_b_num\", \"sitewho_epi\", \"sitewhogen\", \"sitewhogen_num\", \"manual\" or \"no\". \n", 
-      "Default `fill_sites = \"no\"` will be used instead of: ", fill_sites))
+    if(!quiet){
+      rlang::warn(c(
+        "Parameter `fill_sites` must be \"icd2d\", \"icd3d\", \"icd10gm2d\", \"sitewho\", \"sitewho_b\", 
+      \"sitewho_num\", \"sitewho_b_num\", \"sitewho_epi\", \"sitewhogen\", \"sitewhogen_num\", \"manual\" or \"no\".", 
+        paste0("Default `fill_sites = \"no\"` will be used instead of: ", fill_sites),
+        ""
+      ))
+    }
     fill_sites <- "no"
   }
   
@@ -240,6 +246,9 @@ calc_refrates <- function(df,
     if(fill_sites[1] == "manual"){
       sites_all <- fill_sites[-1]
     } 
+    
+    sites_all <- as.character(sites_all)
+    
   } else{
     fill <- FALSE
   }
@@ -381,18 +390,13 @@ calc_refrates <- function(df,
     ))
   }
   
-  if(!( c(1) %in% (unique(df[[rlang::as_name(count_var)]])))){
-    rlang::inform(rlang::format_error_bullets(c(
-      "x" = "[CHK_count] A warning with regard to no observations in `count_var` occurred. Check warning message below.")))
-    
+  if(!quiet &!( c(1) %in% (unique(df[[rlang::as_name(count_var)]])))){
     rlang::warn(c(
       "[CHK_count] The column defined in `count_var` does not contain any rows where count_var == 1. So no observed cases are found.",
       "i" = paste0("You have used `count_var = \"", rlang::as_name(count_var), "\"`"),
       "Please make sure that the column of df defined as `count_var` is numeric and coded 1 for observed cases.",
       " "
-    ),
-    .frequency = "always"
-    )
+    ))
   }
   
   # create empty objects for possible warnings and errors
@@ -404,13 +408,13 @@ calc_refrates <- function(df,
   
   ## --- 1a: prepare df
   
-  # remove columns from data.frame that is not needed to safe memory
+  # remove columns from data.frame that is not needed to save memory
   df <- df %>%
-    tidytable::select.(!!!rlang::syms(defined_vars))
+    tidytable::select(!!!rlang::syms(defined_vars))
   
   # change factors to character to avoid warning messages
   df <- df %>%
-    tidytable::mutate.(tidytable::across.(.cols = where(is.factor), .fns = as.character))
+    tidytable::mutate(tidytable::across(.cols = where(is.factor), .fns = as.character))
   
   # remove all labels from df to avoid warning messages
   df[] <- lapply(df, function(x) { attributes(x) <- NULL; x })
@@ -418,40 +422,34 @@ calc_refrates <- function(df,
   
   #make all important variables characters and make NAs explicit (for better matching)
   df <- df %>%
-    tidytable::mutate.(
+    tidytable::mutate(
       age = as.character(!!age_var),
       sex = as.character(!!sex_var),
       region = as.character(!!region_var),
       year = as.character(!!year_var),
       t_site = as.character(!!site_var),
       count_var = as.numeric(!!count_var)) %>%
-    tidytable::mutate.(tidytable::across.(.cols = c(age, sex, region, year, t_site), 
-                                          .fns = ~tidytable::replace_na.(., na_explicit)))
+    tidytable::mutate(tidytable::across(.cols = c(age, sex, region, year, t_site), 
+                                          .fns = ~tidytable::replace_na(., na_explicit)))
   
   #prepare df for race stratification if needed
   if(rs){
     df <- df %>%
-      tidytable::mutate.(
+      tidytable::mutate(
         race = as.character(!!race_var)) %>%
-      tidytable::mutate.(tidytable::across.(.cols = c(race), 
-                                            .fns = ~tidytable::replace_na.(., na_explicit)))
+      tidytable::mutate(tidytable::across(
+        .cols = c(race), 
+        .fns = ~tidytable::replace_na(., na_explicit)))
   }
   
-  # #WIP: evaluate if it would be faster to create fake race var for matching instead of filtering refpop_df
-  # #SEER only, if no race stratification is used, create fake race_var so that only totals remain
-  # if(!rs & dattype == "seer"){
-  #   refpop_df <- refpop_df %>%
-  #     tidytable::filter.(race == "Total - All races")
-  # }
-  
   
   ## --- 1b: get used age, sex, region, year, t_site
   
-  used_age <- unique(df$age)
-  used_sex <- unique(df$sex)
+  used_age    <- unique(df$age)
+  used_sex    <- unique(df$sex)
   used_region <- unique(df$region)
-  used_year <- unique(df$year)
-  used_t_site<- unique(df$t_site)
+  used_year   <- unique(df$year)
+  used_t_site <- unique(df$t_site)
   if(rs){
     used_race <- unique(df$race)
   } else {
@@ -463,7 +461,7 @@ calc_refrates <- function(df,
   
   #make factor variables to character for better matching
   refpop_df <- refpop_df %>%
-    tidytable::mutate.(tidytable::across.(.cols = where(is.factor), .fns = as.character))
+    tidytable::mutate(tidytable::across(.cols = where(is.factor), .fns = as.character))
   
   #remove attributes for better matching
   refpop_df[] <- lapply(refpop_df, function(x) { attributes(x) <- NULL; x })
@@ -477,36 +475,43 @@ calc_refrates <- function(df,
     miss_race <- used_race[!used_race %in% available_race]
     ##take precautions for missing race data in df
     if(length(miss_race) > 0){
-      rlang::inform(c(
-        "[INFO Unknown Race] There are values from race missing in refrates_df.",
-        "i" = "The following values for race_var present in the data, is not availabe in refrates_df:",
+      rlang::warn(c(
+        "[WARN Unknown Race] There are values from race missing in refrates_df.",
+        "x" = "The following values for `race_var` present in the data are not availabe in refrates_df:",
         paste0(" -> ", miss_race),
-        "For all missing reference levels of race, data will be matched to the category 'Total' in refrates_df.",
-        "!" = "It is recommeded to clean race_var before running this function.",
+        "!" = "For missing reference levels of race, no population can be found in refrates_df. Thus, rates will be overestimated.",
+        "i" = "You have two options to fix this problem:",
+        " " = "(1) clean race_var before running this function.",
+        " " = "(2) run function again to calculate rates ignoring race by using `race_var = NULL`",
         " "
       ))
     }
-    ##filter refpop_df to used_race
-    refpop_df <- refpop_df %>%
-      tidytable::filter.(race %in% !!used_race)
   }
   
   
   if(!is.null(dattype)){
-    #SEER only, if no race stratification is used, filter refpop so that only totals remain
+    #SEER only, if no race stratification is used, filter refpop_df so that only totals remain
     if(!rs & dattype == "seer"){
       refpop_df <- refpop_df %>%
-        tidytable::filter.(race == "Total - All races")
+        tidytable::filter(race == "Total - All races")
+    }
+  } else{
+    #possibly dattype is null, but race_var might be present and `race_var = NULL`
+    if(!rs & "race" %in% names(refpop_df)){
+      refpop_df <- refpop_df %>%
+        tidytable::filter(race == "Total - All races")
     }
   }
   
   ## --- 1d: prepare calc_totals option
   
   if(!is.logical(calc_totals)){
-    rlang::warn(c(
-      "Parameter `calc_totals` should be logical (TRUE or FALSE).",
-      "i" = "Default `calc_totals = FALSE` will be used instead.",
-      " "))
+    if(!quiet){
+      rlang::warn(c(
+        "Parameter `calc_totals` should be logical (TRUE or FALSE).",
+        "i" = "Default `calc_totals = FALSE` will be used instead.",
+        " "))
+    }
     calc_totals <- FALSE
   }
   
@@ -521,7 +526,7 @@ calc_refrates <- function(df,
   
   #2a calculate observed
   calc_count <- df %>%
-    tidytable::summarize.(incidence_cases = sum(.data$count_var, na.rm = TRUE), 
+    tidytable::summarize(incidence_cases = sum(.data$count_var, na.rm = TRUE), 
                           .by = tidyselect::all_of(c("age", "sex", "region", "year", "t_site",
                                                      if(rs){"race"}))
     )
@@ -530,37 +535,40 @@ calc_refrates <- function(df,
   #enforce option fill
   
   if(fill == TRUE) {
-    
-    rlang::inform(c(
-      "Option `fill_sites == TRUE` is used.", 
-      "i" = "This means empty strata will be filled for all combinations of used age, sex, year, region, race and sites.",
-      " "
-    ))
+    if(!quiet){
+      rlang::inform(c(
+        "Option `fill_sites == TRUE` is used.", 
+        "i" = "This means empty strata will be filled for all combinations of used age, sex, year, region, race and sites.",
+        " "
+      ))
+    }
     
     complete_vars_quo <- rlang::syms(c("age", "sex", "region", "year", 
                                        if(rs){"race"}))
     
     calc_count <- calc_count %>% #complete groups where i_observed = 0
-      tidytable::complete.(., !!!complete_vars_quo, t_site = !!sites_all) %>%
-      tidytable::mutate.(
-        incidence_cases = tidytable::case_when.(is.na(incidence_cases) ~ 0,
+      tidytable::complete(., !!!complete_vars_quo, t_site = !!sites_all) %>%
+      tidytable::mutate(
+        incidence_cases = tidytable::case_when(is.na(incidence_cases) ~ 0,
                                                 TRUE ~ incidence_cases)) 
   } else{
     #if fill is not used, but totals are calculated, table also needs to be filled
     if(ct){
-      
-      rlang::inform(c(
-        "Option `calc_totals == TRUE` is used.", 
-        "i" = "This means empty strata will be filled for all combinations of used age, sex, year, region, race and site to obtain correct totals for poulation."
-      ))
+      if(!quiet){
+        rlang::inform(c(
+          "[INFO Totals] Option `calc_totals == TRUE` is used.", 
+          "i" = "This means empty strata will be filled for all combinations of used age, sex, year, region, race and site to obtain correct totals for poulation.",
+          " "
+        ))
+      }
       
       complete_vars_quo <- rlang::syms(c("age", "sex", "region", "year", 
                                          if(rs){"race"}, "t_site"))
       
       calc_count <- calc_count %>% #complete groups where i_observed = 0
-        tidytable::complete.(., !!!complete_vars_quo) %>%
-        tidytable::mutate.(
-          incidence_cases = tidytable::case_when.(is.na(incidence_cases) ~ 0,
+        tidytable::complete(., !!!complete_vars_quo) %>%
+        tidytable::mutate(
+          incidence_cases = tidytable::case_when(is.na(incidence_cases) ~ 0,
                                                   TRUE ~ incidence_cases))
     }
   }
@@ -569,30 +577,30 @@ calc_refrates <- function(df,
   
   #CHK for missing strata in refpop_df
   used_strata <- calc_count %>%
-    tidytable::distinct.(tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"})))
+    tidytable::distinct(tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"})))
   
   missing_ref_strata <- used_strata %>%
-    tidytable::anti_join.(refpop_df, by = c("age", "sex", "region" , "year", if(rs){"race"}))
+    tidytable::anti_join(refpop_df, by = c("age", "sex", "region" , "year", if(rs){"race"}))
   
   if(nrow(missing_ref_strata) > 0){
-    problems_missing_refpop_strata_attr <- tidytable::bind_rows.(problems_missing_refpop_strata_attr, missing_ref_strata)
+    problems_missing_refpop_strata_attr <- tidytable::bind_rows(problems_missing_refpop_strata_attr, missing_ref_strata)
   }
   
   #do the matching
   calc_rates <- calc_count %>%
-    tidytable::left_join.(refpop_df, by = c("age", "sex", "region" , "year", if(rs){"race"})) %>%
-    tidytable::select.(-tidyselect::any_of(c("comment")))
+    tidytable::left_join(refpop_df, by = c("age", "sex", "region" , "year", if(rs){"race"})) %>%
+    tidytable::select(-tidyselect::any_of(c("comment")))
   
   rm(calc_count)
   
   #cleanup for race option
   if(rs){
     calc_rates <- calc_rates %>%
-      tidytable::mutate.(race = tidytable::case_when.(
+      tidytable::mutate(race = tidytable::case_when(
         race == na_explicit ~ "Unknown",
         TRUE ~ race
       )) %>%
-      tidytable::replace_na.(list(
+      tidytable::replace_na(list(
         population_pyar = 0,
         population_n_per_year = 0))
   }
@@ -604,86 +612,87 @@ calc_refrates <- function(df,
     used_region <- unique(calc_rates$region) 
     
     sum_rate_reg <- calc_rates %>%
-      tidytable::mutate.(reg_group =  paste0("Total - All included regions: ", paste(used_region, collapse = ", "))) %>%
-      tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+      tidytable::mutate(reg_group =  paste0("Total - All included regions: ", paste(used_region, collapse = ", "))) %>%
+      tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                             population_pyar = sum(population_pyar, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age", "sex", "reg_group", "year", "t_site", if(rs){"race"}))) %>%
-      tidytable::rename.(region = reg_group) 
+      tidytable::rename(region = reg_group) 
     
-    calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_reg)
+    calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_reg)
     rm(sum_rate_reg)
     
     min_age <- min(calc_rates$age, na.rm = TRUE) 
     max_age <- max(calc_rates$age, na.rm = TRUE) 
     
     sum_rate_age <- calc_rates %>%
-      tidytable::mutate.(age_group =  paste0("Total - All included ages: ",  min_age, " - ", max_age)) %>%
-      tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+      tidytable::mutate(age_group =  paste0("Total - All included ages: ",  min_age, " - ", max_age)) %>%
+      tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                             population_pyar = sum(population_pyar, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age_group", "sex", "region", "year", "t_site", if(rs){"race"}))) %>%
-      tidytable::rename.(age = age_group) 
+      tidytable::rename(age = age_group) 
     
-    calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_age)
+    calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_age)
     rm(sum_rate_age)
     
     
     sum_rate_sex <- calc_rates %>%
-      tidytable::mutate.(sex_group = "Total - All sexes") %>%
-      tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+      tidytable::mutate(sex_group = "Total - All sexes") %>%
+      tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                             population_pyar = sum(population_pyar, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age", "sex_group", "region", "year", "t_site", if(rs){"race"}))) %>%
-      tidytable::rename.(sex = sex_group) 
+      tidytable::rename(sex = sex_group) 
     
-    calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_sex)
+    calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_sex)
     rm(sum_rate_sex)
     
     min_year <- min(calc_rates$year, na.rm = TRUE) 
     max_year <- max(calc_rates$year, na.rm = TRUE) 
     
     sum_rate_year <- calc_rates %>%
-      tidytable::mutate.(year_group = paste0("Total - All included years: ", min_year, " - ", max_year)) %>%
-      tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+      tidytable::mutate(year_group = paste0("Total - All included years: ", min_year, " - ", max_year)) %>%
+      tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                             population_pyar = sum(population_pyar, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age", "sex", "region", "year_group", "t_site", if(rs){"race"}))) %>%
-      tidytable::rename.(year = year_group) 
+      tidytable::rename(year = year_group) 
     
-    calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_year)
+    calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_year)
     rm(sum_rate_year)
     
     if(rs){
       used_race <- unique(calc_rates$race)
       
       sum_rate_race <- calc_rates %>%
-        tidytable::mutate.(race_group = paste0("Total - All included races: ", paste(used_race, collapse = ", "))) %>%
-        tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+        tidytable::mutate(race_group = paste0("Total - All included races: ", paste(used_race, collapse = ", "))) %>%
+        tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                               population_pyar = sum(population_pyar, na.rm = TRUE),
                               .by = tidyselect::all_of(c("age", "sex", "region", "year", "t_site", if(rs){"race_group"}))) %>%
-        tidytable::rename.(race = race_group) 
+        tidytable::rename(race = race_group) 
       
-      calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_race)
+      calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_race)
       rm(sum_rate_race)
     }
     
-    used_site <- unique(calc_rates$site)
+    used_site <- unique(calc_rates$t_site)
     
     sum_rate_site_cases <- calc_rates %>%
-      tidytable::mutate.(site_group = paste0("Total - All included cancer sites: ", paste(used_site, collapse = ", "))) %>%
-      tidytable::summarise.(incidence_cases = sum(incidence_cases, na.rm = TRUE),
+      tidytable::mutate(site_group = paste0("Total - All included cancer sites: ", paste(used_site, collapse = ", "))) %>%
+      tidytable::summarise(incidence_cases = sum(incidence_cases, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age", "sex", "region", "year", "site_group", if(rs){"race"}))) %>%
-      tidytable::rename.(t_site = site_group) 
+      tidytable::rename(t_site = site_group) 
     
     #calculate pyar separetly because you cannot add up across sites
     sum_rate_site_pyar <- calc_rates %>%
-      tidytable::summarise.(population_pyar = sum(population_pyar, na.rm = TRUE),
+      tidytable::summarise(population_pyar = sum(population_pyar, na.rm = TRUE),
                             .by = tidyselect::all_of(c("age", "sex", "region", "year", "t_site", if(rs){"race"}))) %>%
-      tidytable::distinct.(tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"}, "population_pyar")), .keep_all = TRUE)
+      tidytable::distinct(tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"}, "population_pyar")), .keep_all = TRUE) %>%
+      tidytable::mutate(t_site = paste0("Total - All included cancer sites: ", paste(used_site, collapse = ", ")))
     
     #merge cases and pyar
     sum_rate_site <- sum_rate_site_cases %>%
-      tidytable::left_join.(sum_rate_site_pyar,
-                            by = tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"})))
+      tidytable::left_join(sum_rate_site_pyar,
+                            by = tidyselect::all_of(c("age", "sex", "region", "year", if(rs){"race"}, "t_site")))
     
-    calc_rates <- tidytable::bind_rows.(calc_rates, sum_rate_site)
+    calc_rates <- tidytable::bind_rows(calc_rates, sum_rate_site)
     rm(sum_rate_site)
     
   } #end ct option
@@ -692,15 +701,16 @@ calc_refrates <- function(df,
   ### 2e Calculate rates
   
   rates_pre <- calc_rates %>%
-    tidytable::mutate.(
-      incidence_crude_rate = tidytable::case_when.(
+    tidytable::mutate(
+      incidence_crude_rate = tidytable::case_when(
         .data$population_pyar > 0 ~ .data$incidence_cases / .data$population_pyar * 100000,
         TRUE                    ~ NA_real_),
       region = as.factor(region),
       sex = as.factor(sex)
     ) %>%
-    tidytable::mutate.(
-      population_n_per_year = tidytable::case_when.(
+    tidytable::mutate(
+      population_n_per_year = tidytable::case_when(
+        stringr::str_detect(.data$year, "^Total - All included years") ~ NA_real_,        
         stringr::str_length(.data$year) == 4 ~ .data$population_pyar,
         stringr::str_length(.data$year) > 4  ~ .data$population_pyar / 5,
         TRUE ~ NA_real_)
@@ -720,26 +730,27 @@ calc_refrates <- function(df,
   #final arranging
   rates <- rates_pre %>%
     #sort variables
-    tidytable::select.(tidyselect::any_of(
+    tidytable::select(tidyselect::any_of(
       c("t_site", "region", "year", "sex", "age", if(rs){"race"}, 
         "incidence_cases", "incidence_crude_rate", "population_pyar", "population_n_per_year")
     )) %>%
     #sort dataset
-    tidytable::arrange.(!!!final_sort_var_quo)
+    tidytable::arrange(!!!final_sort_var_quo)
   
   #write attributes for matched strata
   attr(rates, "strata_var_names") <- used_strata
   
   #write attributes for error and warning messages
   if(nrow(problems_missing_refpop_strata_attr) > 0){
-    
-    rlang::inform(c(
-      "[INFO Reference Population Missing] For some strata no population can be found.",
-      "i" = paste0(nrow(problems_missing_refpop_strata_attr), " strata have no reference population in `refpop_df`"),
-      " - Solution could be to add these strata to `refpop_df`.",
-      "!" = "Check attribute `problems_missing_refpop_strata` of results to see what strata are affected.",
-      " "
-    ))
+    if(!quiet){
+      rlang::inform(c(
+        "[INFO Reference Population Missing] For some strata no population can be found.",
+        "i" = paste0(nrow(problems_missing_refpop_strata_attr), " strata have no reference population in `refpop_df`"),
+        " - Solution could be to add these strata to `refpop_df`.",
+        "!" = "Check attribute `problems_missing_refpop_strata` of results to see what strata are affected.",
+        " "
+      ))
+    }
     
     attr(rates, "problems_missing_refpop_strata") <- problems_missing_refpop_strata_attr
     
@@ -749,3 +760,4 @@ calc_refrates <- function(df,
   return(rates)
   
 } 
+
